@@ -2,7 +2,7 @@ import http.client
 import json
 import requests # TODO remove this
 from cakework.exceptions import CakeworkError
-
+from ssl import SSLCertVerificationError
 
 # TODO remove the client secret from here for open source version
 # takes scope as a string with APIs separated by a space
@@ -12,7 +12,10 @@ def get_token(client_id, client_secret, scope):
     payload = "{\"client_id\":\"" + client_id + "\",\"client_secret\":\"" + client_secret + "\",\"audience\":\"https://cakework-frontend.fly.dev\",\"grant_type\":\"client_credentials\",\"scope\":\"" + scope + "\"}"
     headers = { 'content-type': "application/json" }
 
-    conn.request("POST", "/oauth/token", payload, headers)
+    try:
+        conn.request("POST", "/oauth/token", payload, headers)
+    except SSLCertVerificationError as e:
+        raise CakeworkError("Your python installation cannot validate SSL certificates. Please install the Certificates.command in your Python root directory")
 
     res = conn.getresponse()
     data = res.read()
